@@ -7,7 +7,7 @@ summary.stratified.data.frame <- function(object,
                      as.numeric(table(object$stratum.index)),
                      round(as.numeric(table(object$stratum.index))/dim(object$data)[1],3)))
 
-  colnames(df) <- c("  Strata bounds","    n","    n (per cent)")
+  colnames(df) <- c("  Strata bounds","    n","    n (proportion)")
 
   sum.str <- list(str.var  = object$stratified.by,
                   str.info = df)
